import request from '@/utils/request'

//列表
export function studyFormApply_list(query) {
  return request({
    url: '/system/business/studyFormApply/list',
    method: 'get',
    params: query
  })
}
//稽查轨迹
export function studyFormApply_jcgj(query) {
  return request({
    url: '/system/business/studyFormApply/jcgjList',
    method: 'get',
    params: query
  })
}
//签名信息
export function studyFormApply_qmxx(query) {
  return request({
    url: '/system/business/studyFormApply/qmxxList',
    method: 'get',
    params: query
  })
}

//详情
export function studyFormApply_info(query) {
  return request({
    url: '/system/business/studyFormApply/info',
    method: 'get',
    params: query
  })
}
//导出
export function studyFormApply_exportDetail(query) {
  return request({
    url: '/system/business/studyFormApply/exportDetail',
    method: 'get',
    params: query
  })
}
//加签
export function studyFormApply_jq(data) {
  return request({
    url: '/system/business/studyFormApply/jq',
    method: 'post',
    data: data
  })
}

//废止
export function studyFormApply_fz(data) {
  return request({
    url: '/system/business/studyFormApply/fz',
    method: 'post',
    data: data
  })
}

//确认废止
export function studyFormApply_qrfz(data) {
  return request({
    url: '/system/business/studyFormApply/qrfz',
    method: 'post',
    data: data
  })
}

//更换归属人
export function studyFormApply_ghgsr(data) {
  return request({
    url: '/system/business/studyFormApply/ghgsr',
    method: 'post',
    data: data
  })
}

//保存
export function studyFormApply_bc(data) {
  return request({
    url: '/system/business/studyFormApply/bc',
    method: 'post',
    data: data
  })
}

//仅保存
export function studyFormApply_bcOnly(data) {
  return request({
    url: '/system/business/studyFormApply/bcOnly',
    method: 'post',
    data: data
  })
}
//提交
export function studyFormApply_tj(data) {
  return request({
    url: '/system/business/studyFormApply/tj',
    method: 'post',
    data: data
  })
}
//复核通过
export function studyFormApply_fhtg(data) {
  return request({
    url: '/system/business/studyFormApply/fhtg',
    method: 'post',
    data: data
  })
}

//复核拒绝
export function studyFormApply_fhjj(data) {
  return request({
    url: '/system/business/studyFormApply/fhjj',
    method: 'post',
    data: data
  })
}

//审核通过
export function studyFormApply_shtg(data) {
  return request({
    url: '/system/business/studyFormApply/shtg',
    method: 'post',
    data: data
  })
}

//审核拒绝
export function studyFormApply_shjj(data) {
  return request({
    url: '/system/business/studyFormApply/shjj',
    method: 'post',
    data: data
  })
}

//审阅
export function studyFormApply_sy(data) {
  return request({
    url: '/system/business/studyFormApply/sy',
    method: 'post',
    data: data
  })
}

//保存字段勾选记录
export function studyFormApply_updateZdgxjl(data) {
  return request({
    url: '/system/business/studyFormApply/updateZdgxjl',
    method: 'post',
    data: data
  })
}

//保存复核意见
export function studyFormApply_updateFhyjjl(data) {
  return request({
    url: '/system/business/studyFormApply/updateFhyjjl',
    method: 'post',
    data: data
  })
}

//保存表单内容
export function studyFormApply_updateBdnr(data) {
  return request({
    url: '/system/business/studyFormApply/updateBdnr',
    method: 'post',
    data: data
  })
}